@@ -32,8 +32,6 @@
 #include <Okteta/Versionable>
 #include <Okteta/TextByteArrayAnalyzer>
 #include <Okteta/Bookmark>
-// KF
-#include <KLocalizedString>
 // Qt
 #include <QScroller>
 #include <QPainter>
@@ -45,7 +43,9 @@
 #include <QGestureEvent>
 #include <QTapGesture>
 #include <QPinchGesture>
+#include <QStyle>
 #include <QStyleHints>
+#include <QInputMethod>
 #include <QApplication>
 #include <QToolTip>
 #include <QMimeData>
@@ -61,8 +61,6 @@ static constexpr Address DefaultFirstLineOffset = 0;
 
 // zooming is done in steps of font size points
 static constexpr int DefaultZoomStep = 1;
-static constexpr int MinFontPointSize = 2;
-static constexpr int MaxFontPointSize = 96;
 
 static constexpr AbstractByteArrayView::ValueCoding DefaultValueCoding =  AbstractByteArrayView::HexadecimalCoding;
 static constexpr AbstractByteArrayView::CharCoding DefaultCharCoding = AbstractByteArrayView::LocalEncoding;
@@ -146,7 +144,7 @@ AbstractByteArrayViewPrivate::AbstractByteArrayViewPrivate(AbstractByteArrayView
     , mCursorPaused(false)
     , mBlinkCursorVisible(false)
     , mCursorVisible(false)
-    // , mDefaultFontSize( p->font().pointSize() ) crashes in font()
+    , m_wasFocussedByMouseClick(false)
     , mResizeStyle(DefaultResizeStyle)
 {
 }
@@ -185,10 +183,9 @@ void AbstractByteArrayViewPrivate::init()
 {
     Q_Q(AbstractByteArrayView);
 
-    // TODO: check if the crash reported above for mDefaultFontSize still holds
+    // TODO: check if the crash noted with the constructor of FontScalingZoomState still holds
     // if not, move to constructor init
-    m_scaledFont = q->font();
-    mDefaultFontSize = m_scaledFont.pointSize();
+    m_fontScalingZoomState.initFont(q->font());
 
     // initialize layout
     mTableLayout->setLength(mByteArrayModel->size());
@@ -224,6 +221,9 @@ void AbstractByteArrayViewPrivate::init()
 
     setWheelController(mZoomWheelController);
 
+    q->setAttribute(Qt::WA_InputMethodEnabled);
+    q->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
+
     QObject::connect(QGuiApplication::styleHints(), &QStyleHints::cursorFlashTimeChanged,
                      q, [this](int flashTime) { onCursorFlashTimeChanged(flashTime); });
 
@@ -339,47 +339,25 @@ void AbstractByteArrayViewPrivate::changeEvent(QEvent* event)
     q->ColumnsView::changeEvent(event);
 
     if (event->type() == QEvent::FontChange) {
-        // remember current state
-        const int currentScaledPointSize = m_scaledFont.pointSize();
-
-        // set new font to current fontsize
-        m_scaledFont = q->font();
-        mDefaultFontSize = m_scaledFont.pointSize();
-        m_zoomOutLevels = (MinFontPointSize < mDefaultFontSize) ? mDefaultFontSize - MinFontPointSize : 0;
-        m_zoomInLevels = (mDefaultFontSize < MaxFontPointSize) ? MaxFontPointSize - mDefaultFontSize : 0;
-
-        m_scaledFont.setPointSize(currentScaledPointSize);
-        m_zoomScale = (double)currentScaledPointSize / mDefaultFontSize;
+        // update rendering font to new font, using current scaling
+        m_fontScalingZoomState.setFont(q->font());
 
         adjustTToScaledFont();
 
         // might this need atomic signalling rather?
-        emit q->zoomLevelChanged(m_zoomScale);
+        emit q->zoomLevelChanged(m_fontScalingZoomState.scale());
         emit q->zoomLevelsChanged();
     }
 }
 
 double AbstractByteArrayViewPrivate::zoomScaleForLevel(int level)   const
 {
-    if (m_zoomOutLevels < -level) {
-        level = -m_zoomOutLevels;
-    } else if (m_zoomInLevels < level) {
-        level = m_zoomInLevels;
-    }
-    const int newPointSize = mDefaultFontSize + level;
-    return static_cast<double>(newPointSize) / mDefaultFontSize;
+    return m_fontScalingZoomState.scaleForLevel(level);
 }
 
 int AbstractByteArrayViewPrivate::zoomLevelForScale(double zoomScale) const
 {
-    const double pointSize = zoomScale * mDefaultFontSize;
-    int level = static_cast<int>(pointSize - mDefaultFontSize);
-    if (m_zoomOutLevels < -level) {
-        level = -m_zoomOutLevels;
-    } else if (m_zoomInLevels < level) {
-        level = m_zoomInLevels;
-    }
-    return level;
+    return m_fontScalingZoomState.levelForScale(zoomScale);
 }
 
 void AbstractByteArrayViewPrivate::zoomIn()  { zoomIn(DefaultZoomStep); }
@@ -389,92 +367,53 @@ void AbstractByteArrayViewPrivate::zoomIn(int pointIncrement)
 {
     Q_Q(AbstractByteArrayView);
 
-    int newPointSize = m_scaledFont.pointSize() + pointIncrement;
-    if (newPointSize > MaxFontPointSize) {
-        newPointSize = MaxFontPointSize;
-    }
-
-    m_scaledFont.setPointSize(newPointSize);
-    m_zoomScale = (double)newPointSize / mDefaultFontSize;
+    m_fontScalingZoomState.zoomIn(pointIncrement);
 
     adjustTToScaledFont();
 
-    emit q->zoomLevelChanged(m_zoomScale);
+    emit q->zoomLevelChanged(m_fontScalingZoomState.scale());
 }
 
 void AbstractByteArrayViewPrivate::zoomOut(int pointDecrement)
 {
     Q_Q(AbstractByteArrayView);
 
-    int newPointSize = m_scaledFont.pointSize() - pointDecrement;
-    if (newPointSize < MinFontPointSize) {
-        newPointSize = MinFontPointSize;
-    }
-
-    m_scaledFont.setPointSize(newPointSize);
-    m_zoomScale = (double)newPointSize / mDefaultFontSize;
+    m_fontScalingZoomState.zoomOut(pointDecrement);
 
     adjustTToScaledFont();
 
-    emit q->zoomLevelChanged(m_zoomScale);
+    emit q->zoomLevelChanged(m_fontScalingZoomState.scale());
 }
 
 void AbstractByteArrayViewPrivate::zoomTo(int newPointSize)
 {
     Q_Q(AbstractByteArrayView);
 
-    if (newPointSize < MinFontPointSize) {
-        newPointSize = MinFontPointSize;
-    } else if (newPointSize > MaxFontPointSize) {
-        newPointSize = MaxFontPointSize;
-    }
-
-    if (m_scaledFont.pointSize() == newPointSize) {
+    if (!m_fontScalingZoomState.zoomTo(newPointSize)) {
         return;
     }
 
-    m_scaledFont.setPointSize(newPointSize);
-    m_zoomScale = (double)newPointSize / mDefaultFontSize;
-
     adjustTToScaledFont();
 
-    emit q->zoomLevelChanged(m_zoomScale);
+    emit q->zoomLevelChanged(m_fontScalingZoomState.scale());
 }
 
 void AbstractByteArrayViewPrivate::unZoom()
 {
-    zoomTo(mDefaultFontSize);
+    zoomTo(m_fontScalingZoomState.defaultFontSize());
 }
 
 void AbstractByteArrayViewPrivate::setZoomScale(double zoomScale)
 {
     Q_Q(AbstractByteArrayView);
 
-    const int currentPointSize = m_scaledFont.pointSize();
-
-    // TODO: here we catch any new zoom scales which are out of bounds and the zoom already at that bound
-    if ((currentPointSize <= MinFontPointSize && zoomScale < (double)MinFontPointSize / mDefaultFontSize)
-        || (MaxFontPointSize <= currentPointSize && (double)MaxFontPointSize / mDefaultFontSize < zoomScale)) {
+    if (!m_fontScalingZoomState.setScale(zoomScale)) {
         return;
     }
 
-    int newPointSize = (int)(zoomScale * mDefaultFontSize);
-    if (newPointSize < MinFontPointSize) {
-        newPointSize = MinFontPointSize;
-    } else if (newPointSize > MaxFontPointSize) {
-        newPointSize = MaxFontPointSize;
-    }
-
-    // other than in zoomTo(), where the new zoom scale is calculated from the integers, here
-    // use the passed zoom scale value, to avoid getting trapped inside a small integer value,
-    // if the zoom tool operates relatively
-    // think about, if this is the right approach
-    m_scaledFont.setPointSize(newPointSize);
-    m_zoomScale = zoomScale;
-
     adjustTToScaledFont();
 
-    emit q->zoomLevelChanged(m_zoomScale);
+    emit q->zoomLevelChanged(m_fontScalingZoomState.scale());
 }
 
 void AbstractByteArrayViewPrivate::setStartOffset(Address startOffset)
@@ -1069,7 +1008,7 @@ void AbstractByteArrayViewPrivate::initPainterFromWidget(QPainter* painter) cons
     const QPalette& palette = q->palette();
     painter->setPen(QPen(palette.brush(q->foregroundRole()), 1));
     painter->setBrush(palette.brush(q->backgroundRole()));
-    painter->setFont(m_scaledFont);
+    painter->setFont(renderingFont());
 }
 
 QMenu* AbstractByteArrayViewPrivate::createStandardContextMenu(QPoint position)
@@ -1093,6 +1032,15 @@ QMenu* AbstractByteArrayViewPrivate::createStandardContextMenu(QPoint position)
     return menu;
 }
 
+void AbstractByteArrayViewPrivate::keyPressEvent(QKeyEvent* keyEvent)
+{
+    Q_Q(AbstractByteArrayView);
+
+    if (!controller()->handleKeyPress(keyEvent)) {
+        q->ColumnsView::keyPressEvent(keyEvent);
+    }
+}
+
 void AbstractByteArrayViewPrivate::mousePressEvent(QMouseEvent* mouseEvent)
 {
     Q_Q(AbstractByteArrayView);
@@ -1115,6 +1063,13 @@ void AbstractByteArrayViewPrivate::mouseMoveEvent(QMouseEvent* mouseEvent)
     }
 }
 
+bool isStyleRequestingSoftwareInputPanelOnMouseClick(QWidget* widget)
+{
+    const QStyle::RequestSoftwareInputPanel behavior = QStyle::RequestSoftwareInputPanel(
+                    widget->style()->styleHint(QStyle::SH_RequestSoftwareInputPanel));
+    return (behavior == QStyle::RSIP_OnMouseClick);
+}
+
 void AbstractByteArrayViewPrivate::mouseReleaseEvent(QMouseEvent* mouseEvent)
 {
     Q_Q(AbstractByteArrayView);
@@ -1124,6 +1079,16 @@ void AbstractByteArrayViewPrivate::mouseReleaseEvent(QMouseEvent* mouseEvent)
     } else {
         q->ColumnsView::mouseReleaseEvent(mouseEvent);
     }
+
+    if (!isEffectiveReadOnly() && q->rect().contains(mouseEvent->pos())) {
+        if (mouseEvent->button() == Qt::LeftButton && qApp->autoSipEnabled()) {
+            if (!m_wasFocussedByMouseClick || isStyleRequestingSoftwareInputPanelOnMouseClick(q)) {
+                QGuiApplication::inputMethod()->show();
+            }
+        }
+    }
+
+    m_wasFocussedByMouseClick = false;
 }
 
 // gets called after press and release instead of a plain press event (?)
@@ -1138,6 +1103,15 @@ void AbstractByteArrayViewPrivate::mouseDoubleClickEvent(QMouseEvent* mouseEvent
     }
 }
 
+void AbstractByteArrayViewPrivate::wheelEvent(QWheelEvent* wheelEvent)
+{
+    Q_Q(AbstractByteArrayView);
+
+    if (!wheelController()->handleWheelEvent(wheelEvent)) {
+        q->ColumnsView::wheelEvent(wheelEvent);
+    }
+}
+
 bool AbstractByteArrayViewPrivate::event(QEvent* event)
 {
     Q_Q(AbstractByteArrayView);
@@ -1272,10 +1246,14 @@ void AbstractByteArrayViewPrivate::focusInEvent(QFocusEvent* focusEvent)
 {
     Q_Q(AbstractByteArrayView);
 
+    const Qt::FocusReason focusReason = focusEvent->reason();
+    if (focusReason == Qt::MouseFocusReason) {
+        m_wasFocussedByMouseClick = true;
+    }
+
     q->ColumnsView::focusInEvent(focusEvent);
     startCursor();
 
-    const Qt::FocusReason focusReason = focusEvent->reason();
     if (focusReason != Qt::ActiveWindowFocusReason
         && focusReason != Qt::PopupFocusReason) {
         emit q->focusChanged(true);
