@@ -24,10 +24,12 @@ class Dropper
 {
 public:
     explicit Dropper(AbstractByteArrayView* view);
-    Dropper() = delete;
+    Dropper(const Dropper&) = delete;
 
     ~Dropper();
 
+    Dropper& operator=(const Dropper&) = delete;
+
 public: // AbstractMouseController API
     bool handleDragEnterEvent(QDragEnterEvent* dragEnterEvent);
     bool handleDragMoveEvent(QDragMoveEvent* dragMoveEvent);
