@@ -23,8 +23,12 @@ class Cursor
 {
 public:
     Cursor();
+    Cursor(const Cursor&) = delete;
+
     virtual ~Cursor();
 
+    Cursor& operator=(const Cursor&) = delete;
+
 public:
     /** sets size of the full cursor */
     void setSize(PixelX Width, PixelY Height, qreal devicePixelRatio);
