@@ -7,6 +7,7 @@
 */
 
 #include "printtool.hpp"
+#include "printtool-config.hpp"
 
 // controller
 #include "printjob.hpp"
@@ -32,8 +33,6 @@
 // Qt
 #include <QApplication>
 #include <QPrinter>
-#include <QFont>
-#include <QFontMetrics>
 
 namespace Kasten {
 
