@@ -15,9 +15,7 @@
 #include <Kasten/StatusBar>
 // Okteta core
 #include <Okteta/CharCodec>
-#include <Okteta/OktetaCore>
 // KF
-#include <KSqueezedTextLabel>
 #include <KComboBox>
 #include <KLocalizedString>
 // Qt
