@@ -179,7 +179,7 @@ bool ByteArrayIHexStreamEncoder::encodeDataToStream(QIODevice* device,
                                                     const Okteta::AbstractByteArrayModel* byteArrayModel,
                                                     const Okteta::AddressRange& range)
 {
-    Q_UNUSED(byteArrayView);
+    Q_UNUSED(byteArrayView)
 
     bool success = true;
 
