@@ -199,7 +199,7 @@ bool ByteArraySRecStreamEncoder::encodeDataToStream(QIODevice* device,
                                                     const Okteta::AbstractByteArrayModel* byteArrayModel,
                                                     const Okteta::AddressRange& range)
 {
-    Q_UNUSED(byteArrayView);
+    Q_UNUSED(byteArrayView)
 
     bool success = true;
 
