@@ -16,12 +16,11 @@
 #include <Kasten/AbstractModelExporterConfigEditor>
 // Kasten core
 #include <Kasten/ModelCodecManager>
-#include <Kasten/AbstractDocument>
+#include <Kasten/AbstractModel>
 #include <Kasten/AbstractModelExporter>
 #include <Kasten/AbstractModelSelection>
 // KF
 #include <KXMLGUIClient>
-#include <KXMLGUIFactory>
 #include <KActionCollection>
 #include <KLocalizedString>
 #include <KSelectAction>
