@@ -10,10 +10,9 @@
 
 // Kasten gui
 #include <Kasten/DataSelectable>
-#include <Kasten/AbstractView>
+#include <Kasten/AbstractModel>
 // KF
 #include <KXMLGUIClient>
-#include <KLocalizedString>
 #include <KActionCollection>
 #include <KStandardAction>
 // Qt
