@@ -27,13 +27,13 @@ void AbstractModelFileSystemSynchronizerPrivate::startFileWatching()
     if (!mDirWatch) {
         mDirWatch = new KDirWatch(q);
         QObject::connect(mDirWatch, &KDirWatch::dirty,
-                         q, [&](const QString& path) { onFileDirty(path); });
+                         q, [this](const QString& path) { onFileDirty(path); });
 
         QObject::connect(mDirWatch, &KDirWatch::created,
-                         q, [&](const QString& path) { onFileCreated(path); });
+                         q, [this](const QString& path) { onFileCreated(path); });
 
         QObject::connect(mDirWatch, &KDirWatch::deleted,
-                         q, [&](const QString& path) { onFileDeleted(path); });
+                         q, [this](const QString& path) { onFileDeleted(path); });
     }
 
     mDirWatch->addFile(mUrl.toLocalFile());
@@ -72,7 +72,7 @@ void AbstractModelFileSystemSynchronizerPrivate::startNetworkWatching()
 
     mNetworkConfigurationManager = new QNetworkConfigurationManager();
     QObject::connect(mNetworkConfigurationManager, &QNetworkConfigurationManager::onlineStateChanged,
-                     q, [&](bool online) { onOnlineStateChanged(online); });
+                     q, [this](bool online) { onOnlineStateChanged(online); });
 }
 void AbstractModelFileSystemSynchronizerPrivate::stopNetworkWatching()
 {
